# Bootstrapping because the main devassistant package depends on DAP packages,
# which in turn require devassistant-devel.
#
# Set this to 0 after we've bootstrapped
%{!?_with_bootstrap: %global bootstrap 0}

%global shortname da

Name:           devassistant
Version:        0.11.2
Release:        7%{?dist}
Summary:        DevAssistant - Making life easier for developers

License:        GPLv2+ and CC-BY-SA
URL:            https://devassistant.org
Source0:        https://pypi.python.org/packages/source/d/%{name}/%{name}-%{version}.tar.gz

# Source1 and Source2 are in upstream now
Source3:        %{name}.macros

# https://github.com/devassistant/devassistant/issues/402
Patch0:         %{name}-resizable.patch

BuildArch:      noarch

BuildRequires:  desktop-file-utils
BuildRequires:  python3-pytest
BuildRequires:  python3-devel
BuildRequires:  python3-dapp
BuildRequires:  python3-flexmock
BuildRequires:  python3-jinja2
BuildRequires:  python3-progress
BuildRequires:  python3-requests
BuildRequires:  python3-scripttest
BuildRequires:  python3-setuptools
BuildRequires:  python3-six
BuildRequires:  python3-PyYAML
%ifarch x86_64
BuildRequires:  python3-docker-py
%endif # arch
BuildRequires:  /usr/bin/ssh-agent

Requires:       %{name}-core = %{version}-%{release}
Requires:       %{name}-gui = %{version}-%{release}
Requires:       %{name}-cli = %{version}-%{release}

# Assistant packages
%if ! 0%{?bootstrap}
# Some of the older packages would not work with this version of devassistant
# Don't confuse 0.11 with devassistant version and don't use %%{version} here!
Requires:       devassistant-dap-c >= 0.11
Requires:       devassistant-dap-cpp >= 0.11
Requires:       devassistant-dap-custom
Requires:       devassistant-dap-dap >= 1.3
Requires:       devassistant-dap-devassistant >= 0.11
Requires:       devassistant-dap-docker >= 0.11
Requires:       devassistant-dap-eclipse
Requires:       devassistant-dap-github
Requires:       devassistant-dap-java  >= 0.11.1
Requires:       devassistant-dap-nodejs >= 0.11
Requires:       devassistant-dap-perl >= 0.11
Requires:       devassistant-dap-php >= 0.11
Requires:       devassistant-dap-python >= 0.11
Requires:       devassistant-dap-ruby >= 0.11
Requires:       devassistant-dap-tito
Requires:       devassistant-dap-vim
%endif # bootstrap

%global __requires_exclude ^\(/usr/bin/php\|/usr/bin/perl\|perl\\(\)

%description
DevAssistant can help you with creating and setting up basic projects
in various languages, installing dependencies, setting up environmens,
working with source control, etc.

This package will install both the command-line and graphical interfaces.

%package core
Summary:        The core packages of DevAssistant
# it seems that other packages using bash-completion don't depend
# on it and rather just own the directory, so we will do the same
Requires:       git
# needed to create ssh key for GitHub access, not necessarily installed by default everywhere
Requires:       openssh-askpass
Requires:       polkit
Requires:       python3-dapp
Requires:       python3-dnf
Requires:       python3-jinja2
Requires:       python3-progress
Requires:       python3-github
Requires:       python3-requests
Requires:       python3-setuptools
Requires:       python3-six
Requires:       python3-PyYAML
%ifarch x86_64
Requires:       python3-docker-py
%endif # arch

%description core
This package contains the DevAssistant core files only. To actually run
DevAssistant, you need also a package that provides devassistant-ui, such as
devassistant-cli or devassistant-gui.

%package gui
Summary:        DevAssistant GUI written in GTK+
Requires:       python3-gobject
Requires:       python3-six
Requires:       %{name}-core = %{version}-%{release}
Provides:       %{name}-ui = %{version}-%{release}

%description gui
This package contains the GTK+ GUI for DevAssistant. If you install this
package, you will get full DevAssistant functionality. The DevAssistant
command-line UI is provided by the package devassistant-cli.

%package cli
Summary:        DevAssistant command-line UI
Requires:       python3-six
Requires:       %{name}-core = %{version}-%{release}
Provides:       %{name}-ui = %{version}-%{release}

%description cli
This package contains the command-line UI for DevAssistant. If you install this
package, you will get full DevAssistant functionality. The DevAssistant GTK+
GUI is provided by the package devassistant-gui.

%package devel
Summary:        Macros needed for DAP packages distributed via RPM.
# CLI needed for installing and linting
Requires:       devassistant-cli
# 0.1.9 is now sync with the guidelines
Requires:       dap2rpm >= 0.1.9

%description devel
Macros needed for DAP packages distributed via RPM.

%prep
%setup -q -n %{name}-%{version}

%patch0 -p1

# remove bundled egg-info
rm -rf %{name}.egg-info

sed -i '/Version/d' distribution/%{name}.desktop
find -name '*.py' | xargs sed -i '1s,^#!\(/usr/bin/\|/usr/bin/env \)python,#!%{__python3},'

# generate manpages from source
pushd distribution/manpages
    %{__python3} generate_man.py
popd

%build
%{__python3} setup.py build

%install
%{__python3} setup.py install --skip-build --root %{buildroot}

# folder for assistants
mkdir -p %{buildroot}%{_datadir}/%{name}/{assistants,files,icons,meta,snippets,doc}
mkdir -p %{buildroot}%{_datadir}/%{name}/{assistants,files,icons}/{crt,twk,prep,extra}
mkdir -p %{buildroot}%{_datadir}/%{name}/files/snippets

# manpages
mkdir -p %{buildroot}%{_mandir}/man1
install -p -m 644 distribution/manpages/%{shortname}.1 %{buildroot}%{_mandir}/man1
install -p -m 644 distribution/manpages/%{shortname}-gui.1 %{buildroot}%{_mandir}/man1
install -p -m 644 distribution/manpages/%{name}.1 %{buildroot}%{_mandir}/man1
install -p -m 644 distribution/manpages/%{name}-gui.1 %{buildroot}%{_mandir}/man1

# bash completion script
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d/
install -p -m 644 distribution/%{shortname}.bash %{buildroot}%{_sysconfdir}/bash_completion.d/

# icons
for SIZE in 16x16 22x22 24x24 32x32 48x48 256x256; do
    mkdir -p %{buildroot}%{_datadir}/icons/hicolor/$SIZE/apps
    install -p -m 644 distribution/icons/hicolor/$SIZE/%{name}.png %{buildroot}%{_datadir}/icons/hicolor/$SIZE/apps/%{name}.png
done

# symbolic icon
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/symbolic/apps
install -p -m 644 distribution/icons/hicolor/symbolic/%{name}-symbolic.svg %{buildroot}%{_datadir}/icons/hicolor/symbolic/apps/%{name}-symbolic.svg


# desktop and appdata
desktop-file-install --dir %{buildroot}%{_datadir}/applications distribution/%{name}.desktop
mkdir -p %{buildroot}/%{_datadir}/appdata
cp -a distribution/appdata/devassistant.appdata.xml %{buildroot}/%{_datadir}/appdata

# polkit
mkdir -p %{buildroot}%{_datadir}/polkit-1/actions/
install -p -m 644 distribution/polkit/devassistant_auth.policy %{buildroot}%{_datadir}/polkit-1/actions/
mkdir -p %{buildroot}%{_libexecdir}
install -p -m 755 distribution/polkit/da_auth %{buildroot}%{_libexecdir}

#macros
mkdir -p %{buildroot}%{_rpmconfigdir}/macros.d/
cp %{SOURCE3} %{buildroot}%{_rpmconfigdir}/macros.d/macros.%{name}

%check
# -k "not test_doc" added because this tests fails in mock for no obvious reason
#   will fix that in upstream https://github.com/devassistant/devassistant/issues/375
# make sure that there are exactly 7 failed tests because of https://github.com/has207/flexmock/pull/100
# disable test entirely for now
#%{__python3} setup.py test -t py.test-%{python3_version} -- -m "not webtest" -k "not test_doc" | grep "4 failed"

%post gui
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun gui
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans gui
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%files
%license LICENSE
%doc README.rst CONTRIBUTORS

%files core
%license LICENSE
%doc README.rst CONTRIBUTORS
%{_datadir}/%{name}
%{_datadir}/polkit-1/actions/%{name}_auth.policy
%{_libexecdir}/da_auth
%{python3_sitelib}/%{name}
%exclude %{python3_sitelib}/%{name}/gui
%exclude %{python3_sitelib}/%{name}/cli
%{python3_sitelib}/%{name}-%{version}-py?.?.egg-info

%files gui
%license LICENSE
%doc README.rst CONTRIBUTORS
%{_bindir}/%{name}-gui
%{_bindir}/%{shortname}-gui
%{_datadir}/applications/%{name}.desktop
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/symbolic/apps/%{name}-symbolic.svg
%{_mandir}/man1/%{name}-gui.1.gz
%{_mandir}/man1/%{shortname}-gui.1.gz
%{python3_sitelib}/%{name}/gui

%files cli
%license LICENSE
%doc README.rst CONTRIBUTORS
%{_bindir}/%{name}
%{_bindir}/%{shortname}
%{_mandir}/man1/%{shortname}.1.gz
%{_mandir}/man1/%{name}.1.gz
%{_sysconfdir}/bash_completion.d/
%{python3_sitelib}/%{name}/cli

%files devel
%license LICENSE
%doc README.rst CONTRIBUTORS
%{_rpmconfigdir}/macros.d/macros.%{name}

%changelog
* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.11.2-7
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu May 12 2016 Miro Hrončok <mhroncok@redhat.com> - 0.11.2-6
- Add patch for upstream issue #402
- Disable tests,as flexmock appears to be broken

* Mon Feb 15 2016 Slavek Kabrda <bkabrda@redhat.com> - 0.11.2-5
- Expect only 4 tests to fail due to fixed upstream issue in flexmock

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.11.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Nov 24 2015 Slavek Kabrda <bkabrda@redhat.com> - 0.11.2-3
- Expect 7 tests to fail as a result of flexmock bug not yet fixed upstream

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.11.2-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Thu Sep 17 2015 Miro Hrončok <mhroncok@redhat.com> - 0.11.2-1
- New upstream bugfix release
- Remove merged patches

* Tue Jun 23 2015 Tomas Radej <tradej@redhat.com> - 0.11.1-4
- Macro workaround for GH issue devassistant/devassistant#378 that causes all DAPs to FTBFS

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.11.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon May 11 2015 Miro Hrončok <mhroncok@redhat.com> - 0.11.1-2
- Add upstream patch to make the GNOME 3 icon work

* Mon May 04 2015 Miro Hrončok <mhroncok@redhat.com> - 0.11.1-1
- New upstream release
- Remove upstreamed patches

* Wed Apr 22 2015 Miro Hrončok <mhroncok@redhat.com> - 0.11.0-2
- Fixed missing import

* Fri Apr 17 2015 Tomas Radej <tradej@redhat.com> - 0.11.0-1
- Updated to latest upstream version
- Updated URL

* Wed Mar 11 2015 Tomas Radej <tradej@redhat.com> - 0.10.3-4
- Added workaround in -devel macros for rhbz#1200761

* Wed Mar 11 2015 Tomas Radej <tradej@redhat.com> - 0.10.3-3
- Added -L option for licensing files to -devel macros
- Added deps on devassistant-dap-{devassistant,eclipse,vim}

* Wed Mar  4 2015 Ville Skyttä <ville.skytta@iki.fi> - 0.10.3-2
- Move rpm macros to %%{_rpmconfigdir}/macros.d (#1074261)

* Thu Feb 05 2015 Tomas Radej <tradej@redhat.com> - 0.10.3-1
- Updated to latest upstream version

* Wed Jan 28 2015 Tomas Radej <tradej@redhat.com> - 0.10.2-1
- Updated to latest upstream version
Moved to Python 3 only
Split off core, cli, gui, devel packages


* Tue Dec 16 2014 Tomas Radej <tradej@redhat.com> - 0.9.3-4
- Fix phpMyAdmin sample location
Resolves: rhbz#1173871

* Mon Dec 15 2014 Tomas Radej <tradej@redhat.com> - 0.9.3-3
- Fix Node.js project creation
Resolves: rhbz#1147119

* Tue Nov 25 2014 Slavek Kabrda <bkabrda@redhat.com> - 0.9.3-2
- Fix NodeJS assistants problems (missing dependencies, bad dirs).
Resolves: rhbz#1167570

* Thu Nov 13 2014 Tomas Radej <tradej@redhat.com> - 0.9.3-1
- Updated to newer upstream version

* Wed Nov 12 2014 Tomas Radej <tradej@redhat.com> - 0.9.2-8
- Incorporated upstream patch in the polkit policy

* Tue Nov 11 2014 Slavek Kabrda <bkabrda@redhat.com> - 0.9.2-7
- Fix installation on "Generic" Fedora builds.
Resolves: rhbz#1162467

* Fri Oct 24 2014 Tomas Radej <tradej@redhat.com> - 0.9.2-6
- Backported custom polkit policy (bz#1156292)

* Wed Oct 08 2014 Slavek Kabrda <bkabrda@redhat.com> - 0.9.2-5
- Fix issue in Django assistant when used with --venv and --py3

* Fri Oct 03 2014 Slavek Kabrda <bkabrda@redhat.com> - 0.9.2-4
- One more fix for java assistants dependencies.

* Fri Oct 03 2014 Slavek Kabrda <bkabrda@redhat.com> - 0.9.2-3
- Fix java assistants dependencies.

* Thu Oct 02 2014 Slavek Kabrda <bkabrda@redhat.com> - 0.9.2-2
- Add openssh-askpass dependency.

* Mon Sep 01 2014 Tomas Radej <tradej@redhat.com> - 0.9.2-1
- Updated to latest upstream version
- Added high contrast icon

* Mon Jun 23 2014 Tomas Radej <tradej@redhat.com> - 0.9.1-2
- Added forgotten changelog

* Mon Jun 23 2014 Tomas Radej <tradej@redhat.com> - 0.9.1-1
- Updated to latest upstream version

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Jun 03 2014 Tomas Radej <tradej@redhat.com> - 0.9.0-1
- Updated to latest upstream version

* Mon Apr 14 2014 Tomas Radej <tradej@redhat.com> - 0.8.0-3
- Added CC-BY-SA to License field because of appdata.xml

* Fri Feb 28 2014 Miro Hrončok <mhroncok@redhat.com> - 0.8.0-2
- Backport fix of GitHub errors.

* Wed Dec 04 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.8.0-1
- Update to 0.8.0.
- Don't create the /usr/local hierarchy, leave it up to users.

* Wed Oct 02 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.7.0-1
- Update to 0.7.0.

* Wed Aug 28 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.6.1-2
- Properly create and own the /usr/local hierarchy.

* Wed Aug 28 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.6.1-1
- Update to 0.6.1.
- Introduce gui, add its dependencies.

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jul 26 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.5.0-1
- Update to 0.5.0.
- Regenerated patch0.

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 0.4.0-3
- Perl 5.18 rebuild

* Wed Jul 03 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.4.0-2
- Fix manpage typo, rhbz#980646.

* Mon Jul 01 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.4.0-1
- Update to 0.4.0.

* Wed May 15 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.3.1-1
- Update to 0.3.1.
- Remove no longer needed dependencies (jinja2, plumbum).

* Wed Mar 20 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.2.2-1
- Update to 0.2.2 because of minor bug in 0.2.1.

* Wed Mar 20 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.2.1-1
- Update to devassistant 0.2.1.
- Introduce bash completion script.

* Mon Mar 18 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.2.0-1
- Update to devassistant 0.2.0.
- Move assistants and snippets to %%{datadir}/%%{name}.
- Introduce manpage.

* Tue Mar 12 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.1.0-3
- Move templates to %%{_datadir}.

* Tue Mar 12 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.1.0-2
- Use BR: python2-devel instead of python-devel.

* Fri Mar 08 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.1.0-1
- Initial package.
